/*************************************************************************\
*   Copyright (C) 2009-2011 by  Ulf Kreißig <udev@gmx.net>                *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
\*************************************************************************/

#ifndef IONTEST_H
#define IONTEST_H

//--- QT4 ---
#include <QObject>

//--- KDE4 ---
#include <Plasma/DataEngine>
#include <Plasma/Weather/Ion>

class IonTester	: public QObject
{
	Q_OBJECT
public:
	IonTester( QObject * parent = NULL );
	~IonTester();

	void connectSource( const QString & source );
	void reset();

public slots:
	void dataUpdated(const QString & sourceName, const Plasma::DataEngine::Data & data);

	void quit();

private:
	IonInterface * m_pIon;
};

#endif // IONTEST_H
